@@ -33,7 +33,7 @@ class Client(object):
             else:
                 return print('VanityId already exists!')
 
-    def getVanityById(self, vanityId):
+    def getVanityById(self, vanityId: str):
         if self.mongoDb is None:
             return print('Error: no mongoUri defined...')
         else:
@@ -45,9 +45,16 @@ class Client(object):
             else:
                 if self.debugMode == True:
                     print(f"Raw data found: {vanity}")
-
                 return objects.vanityData(vanity)
-                
+    
+    def getUserVanities(self, ownerId: str):
+        if self.mongoDb is None:
+            return print('Error: no mongoUri defined...')
+        else:
+            userVans = self.db.urls.find({ "ownerId": ownerId })
+            if userVans is None:
+                return "No records found..."
+            return objects.ownerVanities(json.loads(userVans)).ownerVanities
 
         # headers = {
         #     "Authorization": apiKey
